Version 0.3.2 (2016-09-01)
==========================
  - fix pip README error

Version 0.3.1 (2016-09-01)
==========================
  - fix version error in documentation

Version 0.3 (2016-08-22)
========================
  - expanding character map by using the character map from the Chinese
    University of Hong Kong (http://bit.ly/2be32he) as based. (Thanks
    Joe Wong)
  - conversion speed improvement
  - fix an encoding bug reported by some users

Version 0.2.2 (2014-08-28)
==========================
  - Integrate ``setup.py`` with unit tests
  - Documentation fixes
  - Continous integration
  - PEP8 compliance
  - Online API documentation
  - Minor enhancement of code

Version 0.2.1 (2014-08-13)
==========================
  - Fixing a bug from distuils.core that stop installation from running

Version 0.2 (2014-08-13)
========================
  - Fixing documentation

Version 0.1 (2014-08-12)
========================
  - Initial Release
